# Copyright Contributors to the OpenVDB Project
# SPDX-License-Identifier: MPL-2.0

# Startup script to set the visibility of (and otherwise customize)
# open-source (ASWF) OpenVDB nodes and their native Houdini equivalents
#
# To be installed as <dir>/python2.7libs/pythonrc.py,
# where <dir> is a path in $HOUDINI_PATH.

import hou
import os


# Construct a mapping from ASWF SOP names to names of equivalent
# native Houdini SOPs.
sopcategory = hou.sopNodeTypeCategory()
namemap = {}
for name, sop in sopcategory.nodeTypes().items():
    try:
        nativename = sop.spareData('nativename')
        if nativename:
            namemap[name] = nativename
    except AttributeError:
        pass

# Print the list of correspondences.
#from pprint import pprint
#pprint(namemap)


# Determine which VDB SOPs should be visible in the Tab menu:
# - If $OPENVDB_OPHIDE_POLICY is set to 'aswf', hide AWSF SOPs for which
#   a native Houdini equivalent exists.
# - If $OPENVDB_OPHIDE_POLICY is set to 'native', hide native Houdini SOPs
#   for which an ASWF equivalent exists.
# - Otherwise, show both the ASWF and the native SOPs.
names = []
ophide = os.getenv('OPENVDB_OPHIDE_POLICY', 'none').strip().lower()
if ophide == 'aswf':
    names = namemap.keys()
elif ophide == 'native':
    names = namemap.values()

for name in names:
    sop = sopcategory.nodeType(name)
    if sop:
        sop.setHidden(True)


# Customize SOP visibility with code like the following:
#
#     # Hide the ASWF Clip SOP.
#     sopcategory.nodeType('DW_OpenVDBClip').setHidden(True)
#
#     # Show the native VDB Clip SOP.
#     sopcategory.nodeType('vdbclip').setHidden(False)
#
#     # Hide all ASWF advection SOPs for which a native equivalent exists.
#     for name in namemap.keys():
#         if 'Advect' in name:
#             sopcategory.nodeType(name).setHidden(True)



# Python script to download the latest Houdini production builds
#
# Note that this can now be replaced with this API:
# https://www.sidefx.com/docs/api/download/index.html
#
# Author: Dan Bailey

import mechanize
import sys
import re
import exceptions

# this argument is for the major.minor version of Houdini to download (such as 15.0, 15.5, 16.0)
version = sys.argv[1]
password = sys.argv[2]

if not re.match('[0-9][0-9]\.[0-9]$', version):
    raise IOError('Invalid Houdini Version "%s", expecting in the form "major.minor" such as "16.0"' % version)

br = mechanize.Browser()
br.set_handle_robots(False)

# login to sidefx.com as openvdb
br.open('https://www.sidefx.com/login/?next=/download/daily-builds')
br.select_form(nr=0)
br.form['username'] = 'openvdb'
br.form['password'] = password
br.submit()

# retrieve download id
br.open('https://www.sidefx.com/download/daily-builds/')

houid = -1

for link in br.links():
    if '/download/download-houdini' not in link.url:
        continue
    if link.text.startswith('houdini-%s' % version) and 'linux_x86_64' in link.text:
        response = br.follow_link(text=link.text, nr=0)
        url = response.geturl()
        houid = url.split('/download-houdini/')[-1]
        break

# download houdini tarball in 50MB chunks
url = 'https://www.sidefx.com/download/download-houdini/%sget/' % houid
response = br.open(url)
mb = 1024*1024
chunk = 50
size = 0
file = open('hou.tar.gz', 'wb')
for bytes in iter((lambda: response.read(chunk*mb)), ''):
    size += 50
    print 'Read: %sMB' % size
    file.write(bytes)
file.close()
